#
# spec file for package keysmith
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without  released
Name:           keysmith
Version:        23.08.4
Release:        1.1
Summary:        OTP client
License:        GPL-3.0-or-later
URL:            https://apps.kde.org/keysmith
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  AppStream
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libsodium-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5Kirigami2)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5QuickControls2)
BuildRequires:  cmake(Qt5Svg)
Requires:       kirigami2
# keysmith's build system doesn't look for it, but it's required at runtime
Requires:       kirigami-addons

%description
OTP client for Plasma Mobile and Desktop

%lang_package

%prep
%autosetup -p1

%build

%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name} --all-name

%files
%doc README.md
%license LICENSES/*
%{_kf5_applicationsdir}/org.kde.keysmith.desktop
%{_kf5_appstreamdir}/org.kde.keysmith.appdata.xml
%{_kf5_bindir}/keysmith
%{_kf5_iconsdir}/hicolor/*/*/*.svg

%files lang -f %{name}.lang

%changelog
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- No code change since 23.08.2
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Add the missing kirigami-addons runtime dependency
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Changes since 23.04.3:
  * flatpak: update runtime to 22.08
  * Fix i18nc to be a title instead of a label
  * Port to MobileForm
  * Fix binary stripping of APKs with Qt 5.15.10
  * Port away from kirigami router
  * gitignore: add QtCreator file
  * Rename clicked() to forceActiveFocus() to make intent clearer
  * Fix giant icon causing binding loops on Setup and Unlock pages
  * Focus the new password field on SetupPassword
  * Add clicked() function to AccountNameForm, now focused when first shown
  * Fix active focus for UnlockAccounts page
  * Fix verticalAlignment binding loop for UnlockAccounts too
  * Use function() syntax in Connections elements
  * Fix binding loop for SetupPassword heading verticalAlignment
  * Show a passive notification when a token is copied to the clipboard
  * Adapt CI to KF6
  * Port to KF6
  * Fix casing
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Sat Mar 18 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
